#!/bin/bash

lsm_file="/sys/kernel/security/lsm"
#内核版本
kernel_version=$(uname -r)
#内核配置文件
config_file="/boot/config-${kernel_version}"
#目标版本
target_version="4.19.90-23.16.v2101.ky10.x86_64"
targetsp3_version="4.19.90-38.0.v2207.ky10.x86_64"

# 分割版本号为子字符串
IFS='.' read -ra kernel_parts <<< "${kernel_version#*-}"
IFS='.' read -ra target_parts <<< "${target_version#*-}"
IFS='.' read -ra targetsp3_parts <<< "${targetsp3_version#*-}"

if grep -q "CONFIG_SECURITY_KYLIN_EXTEND=y" "$config_file"; then
    echo "LSM核外扩展功能工具（适用于V10 SPX系列）"
    echo "LSM核外扩展功能工具检查内核版本"
    echo $kernel_version
    # 逐个比较每个子字符串
    for i in "${!kernel_parts[@]}"; do
        part1="${kernel_parts[$i]}"
        part2="${target_parts[$i]}"
        part3="${targetsp3_parts[$i]}"
        if [ "$part1" \< "$part2" ] && [ "$part1" \< "$part3" ]; then 
            echo "LSM核外扩展功能启用成功！"
            exit 0
        elif [ "$part1" \> "$part2" ] && [ "$part1" \> "$part3" ]; then
            if grep -q  "kyextend" $lsm_file; then
                echo "LSM核外扩展功能启用成功！"
                exit 0
            else
                echo "LSM核外扩展功能未启用成功,建议开启LSM核外扩展功能！"
                echo "建议执行security-switch或setstatus开启任何一个安全模块，可支持LSM核外扩展功能！"
                exit 0
            fi
        elif  [ "$part1" \> "$part2" ] && [ "$part1" \< "$part3" ]; then
            if grep -q  "kyextend"  $lsm_file; then
                echo "LSM核外扩展功能启用成功！"
                exit 0
            else
                echo "LSM核外扩展功能未启用成功,建议开启LSM核外扩展功能！"
                echo "可以通过security-switch或setstatus开启任何一个安全模块，可支持LSM核外扩展功能！"
                exit 0
            fi
		elif   [ "$part1" = "$part2" ] || [ "$part1" = "$part3" ]; then
			if grep -q "kyextend" $lsm_file; then
				echo "LSM核外扩展功能启用成功！"
				exit 0
			else
				echo "LSM核外扩展功能未启用成功,建议开启LSM核外扩展功能！"
				if [ "$part1" = "$part2" ]; then
					echo "可以通过security-switch或setstatus开启任何一个安全模块，可支持LSM核外扩展功能！"
				elif [ "$part1" = "$part3" ]; then
					echo "可以通过security-switch或setstatus开启任何一个安全模块，可支持LSM核外扩展功能！"
				fi
				exit 0
			fi
		fi
    done
    if [ "$kernel_version" \> "$target_version" ]; then
        echo "LSM核外扩展功能未启用成功,建议开启LSM核外扩展功能！"
        echo "可以通过security-switch或setstatus开启任何一个安全模块，可支持LSM核外扩展功能！"
    fi
else
    echo "LSM核外扩展功能工具（适用于V10 SPX系列）"
    echo "LSM核外扩展功能工具检查内核版本"
    echo $kernel_version
    echo "LSM核外扩展功能启用成功！"
fi

